Nim’s Django Helpers
====================

|Build Status| |Coverage Status|

Requirements
------------

-  Python 3.6
-  Django 2.0
-  `django-autoslug <https://github.com/iplweb/django-autoslug-iplweb>`__
-  `django-bootstrap4 <https://github.com/zostera/django-bootstrap4>`__

.. |Build Status| image:: https://travis-ci.org/nim65s/ndh.svg?branch=master
   :target: https://travis-ci.org/nim65s/ndh
.. |Coverage Status| image:: https://coveralls.io/repos/github/nim65s/ndh/badge.svg?branch=master
   :target: https://coveralls.io/github/nim65s/ndh?branch=master
